@@ -1,6 +1,7 @@
 import logging
-from datetime import timedelta
+from datetime import timedelta, datetime
 import traceback
+import time
 
 from django_cron.models import CronJobLog
 
@@ -12,8 +13,9 @@ except ImportError:
 
 
 class Schedule(object):
-    def __init__(self, run_every_mins=60):
+    def __init__(self, run_every_mins=None, run_at_times=[]):
         self.run_every_mins = run_every_mins
+        self.run_at_times = run_at_times
 
 
 class CronJobBase(object):
@@ -39,15 +41,27 @@ class CronJobManager(object):
         Returns a boolean determining whether this cron should run now or not!
         """
         # If we pass --force options, we force cron run
+        self.user_time = None
         if force:
             return True
-        qset = CronJobLog.objects.filter(code=cron_job.code, is_success=True).order_by('-start_time')
-        if qset:
-            previously_ran_successful_cron = qset[0]
-            if timezone.now() < previously_ran_successful_cron.start_time + timedelta(minutes=cron_job.schedule.run_every_mins):
-                return False
-
-        return True
+        if cron_job.schedule.run_every_mins != None:
+            qset = CronJobLog.objects.filter(code=cron_job.code, is_success=True, ran_at_time__isnull=True).order_by('-start_time')
+            if qset:
+                previously_ran_successful_cron = qset[0]
+                if timezone.now() > previously_ran_successful_cron.start_time + timedelta(minutes=cron_job.schedule.run_every_mins):
+                    return True
+            else:
+                return True
+        if cron_job.schedule.run_at_times:
+            for time_data in cron_job.schedule.run_at_times:
+                user_time = time.strptime(time_data, "%H:%M")
+                actual_time = time.strptime("%s:%s" % (datetime.now().hour, datetime.now().minute), "%H:%M")
+                if actual_time >= user_time:
+                    qset = CronJobLog.objects.filter(code=cron_job.code, start_time__gt=datetime.today().date(), ran_at_time=time_data)
+                    if not qset:
+                        self.user_time = time_data
+                        return True
+        return False
 
     @classmethod
     def run(self, cron_job, force=False):
@@ -56,11 +70,9 @@ class CronJobManager(object):
         """
         if not isinstance(cron_job, CronJobBase):
             raise Exception, 'The cron_job to be run should be a subclass of %s' % CronJobBase.__class__
-
         if CronJobManager.__should_run_now(cron_job, force):
             logging.info("Running cron: %s" % cron_job)
             cron_log = CronJobLog(code=cron_job.code, start_time=timezone.now())
-
             try:
                 msg = cron_job.do()
                 cron_log.is_success = True
@@ -68,6 +80,6 @@ class CronJobManager(object):
             except Exception:
                 cron_log.is_success = False
                 cron_log.message = traceback.format_exc()[-1000:]
-
+            cron_log.ran_at_time = self.user_time if self.user_time else None
             cron_log.end_time = timezone.now()
             cron_log.save()
